#!/bin/sh
#======================================================================
# macOS shell script to launch Template Processor (Generator)
#======================================================================

#----------------------------------------------------------------------
# Specify the absolute pathname of FlexDoc/XML home directory
# (by default, derive it from the location of this shell script file)
#----------------------------------------------------------------------
FDH=`cd "$(dirname "${BASH_SOURCE[0]}")/../.." > /dev/null && pwd`
   
#----------------------------------------------------------------------
# -Xmx option sets the maximum heap size allocated by JVM.
#
# Check this option when you need to process large quantities of data!
#
# Note that allocating too much memory isn't good either because it may actually
# decrease the performance, especially when that amount of memory isn't backed
# by the physical RAM on your system.
#
# The JVM options below set the initial Java heap size to 1024 Mb
# and allow extending it up to 2048 Mb.
#----------------------------------------------------------------------
JAVA_OPTIONS="-Xms1024m -Xmx2048m"

#----------------------------------------------------------------------
# FlexDoc/XML module path
#----------------------------------------------------------------------
MODULE_PATH="$FDH/lib/flexdoc-xml.jar:$FDH/lib/xercesImpl.jar"

#----------------------------------------------------------------------
# Run generator with all settings taken from generator.config file
#
# The '-flexdocconfig' option specifies the FlexDoc main configuration
# file prepared for Linux (located in this directory).
#
# (Note: double quotes are needed because file pathnames may contain spaces)
#----------------------------------------------------------------------
java ${JAVA_OPTIONS} --module-path "$MODULE_PATH" --module flexdoc.xml/xyz.flexdoc.xml.Generator \
  -flexdocconfig "$FDH/bin/macOS/flexdoc.config"
